==> deploy-cache-23.1.12-sources.jar: ai/digital/deploy/cache/config/CacheConfiguration.scala <==
package ai.digital.deploy.cache.config

import ai.digital.configuration.central.deploy.{CachesProperties, ClusterProperties}
import com.xebialabs.xlplatform.cluster.ClusterMode.HOT_STANDBY
import grizzled.slf4j.Logging
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.context.annotation.{Bean, Configuration, DependsOn}
import org.springframework.util.StringUtils

import java.net.URI
import javax.cache.spi.CachingProvider
import javax.cache.{CacheManager, Caching}
import scala.jdk.CollectionConverters._

@Configuration
@DependsOn(value = Array("cacheMode"))
class CacheConfiguration(@Autowired cachesProperties: CachesProperties,
                         @Autowired clusterProperties: ClusterProperties,
                         @Autowired cacheConfigurationValidator: CacheConfigurationValidator)
  extends Logging {

  @Bean(destroyMethod = "close")
  def cacheProvider: CacheProvider = {
    try {
      if (!cachesProperties.enabled) {
        logger.error("Caching not enabled in properties. CacheManager not created.")
        return null
      }
      if (clusterProperties.mode.equals(HOT_STANDBY)) {
        logger.error(s"Cluster mode is set to $HOT_STANDBY. CacheManager not created since caching not supported for $HOT_STANDBY.")
        return null
      }
      if (!cacheConfigurationValidator.validate) {
        logger.error("Cache configuration validation failed. CacheManager not created.")
        return null
      }
      new CacheProvider(getCacheManager)
    } catch {
      case exception: Exception =>
        logger.error(s"Exception occurred while creating CacheManager, $exception")
        null
    }
  }

  private def getCacheManager: CacheManager = {
    val cacheManager = if (CacheMode.embeddedCacheMode) {
      getEmbeddedCacheManager
    } else {
      getStandAloneCacheManager
    }
    logger.info(s"cacheManager($cacheManager) of provider(${cacheManager.getCachingProvider}) created.")
    cacheManager
  }

  private def getEmbeddedCacheManager: CacheManager = {
    Caching.getCachingProvider(DEFAULT_EMBEDDED_CACHING_PROVIDER).getCacheManager
  }

  private def getStandAloneCacheManager: CacheManager = {
    getProvider.getCacheManager(getProviderConfigurationFileURI, null)
  }

  private def getProviderConfigurationFileURI: URI = {
    getResource(cachesProperties.providerConfiguration.providerConfigurationFile).toURI
  }

  private def getProvider: CachingProvider = {
    if (StringUtils.hasText(cachesProperties.providerConfiguration.provider)) {
      Caching.getCachingProvider(cachesProperties.providerConfiguration.provider)
    } else {
      Caching.getCachingProviders.asScala.toList.filterNot(provider => {
        provider.toString.contains(DEFAULT_EMBEDDED_CACHING_PROVIDER)
      }).head
    }
  }
}

==> deploy-cache-25.1.0-220.113-sources.jar: ai/digital/deploy/cache/config/CacheConfiguration.scala <==
package ai.digital.deploy.cache.config

import ai.digital.configuration.central.deploy.{CachesProperties, ClusterProperties}
import com.xebialabs.xlplatform.cluster.ClusterMode.HOT_STANDBY
import grizzled.slf4j.Logging
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.context.annotation.{Bean, Configuration, DependsOn, Primary}
import org.springframework.util.StringUtils

import java.net.URI
import javax.cache.spi.CachingProvider
import javax.cache.{CacheManager, Caching}
import scala.jdk.CollectionConverters._

@Configuration
@DependsOn(value = Array("cacheMode"))
class CacheConfiguration(@Autowired cachesProperties: CachesProperties,
                         @Autowired clusterProperties: ClusterProperties,
                         @Autowired cacheConfigurationValidator: CacheConfigurationValidator)
  extends Logging {

  @Primary
  @Bean(destroyMethod = "close")
  def cacheProvider: CacheProvider = {
    try {
      if (!cachesProperties.appCaches.enabled) {
        logger.error("Caching not enabled in properties. CacheManager not created.")
        return null
      }
      if (clusterProperties.mode.equals(HOT_STANDBY)) {
        logger.error(s"Cluster mode is set to $HOT_STANDBY. CacheManager not created since caching not supported for $HOT_STANDBY.")
        return null
      }
      if (!cacheConfigurationValidator.validate) {
        logger.error("Cache configuration validation failed. CacheManager not created.")
        return null
      }
      new CacheProvider(getCacheManager)
    } catch {
      case exception: Exception =>
        logger.error(s"Exception occurred while creating CacheManager, $exception")
        null
    }
  }

  @Bean(name = Array("defaultEmbeddedCacheProvider"),destroyMethod = "close")
  def defaultEmbeddedCacheProvider: CacheProvider = {
    try {
      if (!cachesProperties.systemCaches.enabled || !cachesProperties.systemCaches.jythonScriptCacheConfiguration.enabled) {
        logger.error("Caching not enabled for System cache. CacheManager not created.")
        return null
      }
      new CacheProvider(getEmbeddedCacheManager)
    } catch {
      case exception: Exception =>
        logger.error(s"Exception occurred while creating CacheManager, $exception")
        null
    }
  }

  private def getCacheManager: CacheManager = {
    val cacheManager = if (CacheMode.embeddedCacheMode) {
      getEmbeddedCacheManager
    } else {
      getStandAloneCacheManager
    }
    logger.info(s"cacheManager($cacheManager) of provider(${cacheManager.getCachingProvider}) created.")
    cacheManager
  }

  private def getEmbeddedCacheManager: CacheManager = {
    Caching.getCachingProvider(DEFAULT_EMBEDDED_CACHING_PROVIDER).getCacheManager
  }

  private def getStandAloneCacheManager: CacheManager = {
    getProvider.getCacheManager(getProviderConfigurationFileURI, null)
  }

  private def getProviderConfigurationFileURI: URI = {
    getResource(cachesProperties.appCaches.providerConfiguration.providerConfigurationFile).toURI
  }

  private def getProvider: CachingProvider = {
    if (StringUtils.hasText(cachesProperties.appCaches.providerConfiguration.provider)) {
      Caching.getCachingProvider(cachesProperties.appCaches.providerConfiguration.provider)
    } else {
      Caching.getCachingProviders.asScala.toList.filterNot(provider => {
        provider.toString.contains(DEFAULT_EMBEDDED_CACHING_PROVIDER)
      }).head
    }
  }
}
